pub enum ViAction {
Show 18 variants
ToggleNormalSelection,
ToggleLineSelection,
ToggleBlockSelection,
ToggleSemanticSelection,
SearchNext,
SearchPrevious,
SearchStart,
SearchEnd,
Open,
CenterAroundViCursor,
InlineSearchForward,
InlineSearchBackward,
InlineSearchForwardShort,
InlineSearchBackwardShort,
InlineSearchNext,
InlineSearchPrevious,
SemanticSearchForward,
SemanticSearchBackward,
}Expand description
Vi mode specific actions.
Variants
ToggleNormalSelection
Toggle normal vi selection.
ToggleLineSelection
Toggle line vi selection.
ToggleBlockSelection
Toggle block vi selection.
ToggleSemanticSelection
Toggle semantic vi selection.
SearchNext
Jump to the beginning of the next match.
SearchPrevious
Jump to the beginning of the previous match.
SearchStart
Jump to the next start of a match to the left of the origin.
SearchEnd
Jump to the next end of a match to the right of the origin.
Open
Launch the URL below the vi mode cursor.
CenterAroundViCursor
Centers the screen around the vi mode cursor.
InlineSearchForward
Search forward within the current line.
InlineSearchBackward
Search backward within the current line.
InlineSearchForwardShort
Search forward within the current line, stopping just short of the character.
InlineSearchBackwardShort
Search backward within the current line, stopping just short of the character.
InlineSearchNext
Jump to the next inline search match.
InlineSearchPrevious
Jump to the previous inline search match.
SemanticSearchForward
Search forward for selection or word under the cursor.
SemanticSearchBackward
Search backward for selection or word under the cursor.